@@ -11,7 +11,7 @@ import pandas as pd
 
 class GSDBS:
     def __init__(self):
-        self.version = "0.1.7"
+        self.version = "0.1.9"
         self.credentials = None
         self.accessToken = None
         self.dtablename = None
@@ -301,7 +301,7 @@ class GSDBS:
 
     # ---------
     async def asyncSchemaQuery(self, dtablename):
-        statement = "{ __type(name: \"" + "gun" + "\") {name fields { name type { name kind } } } }"
+        statement = "{ __type(name: \"" + dtablename + "\") {name fields { name type { name kind } } } }"
         try:
             result = await self.asyncExecuteStatement(statement)
         except:
@@ -309,7 +309,7 @@ class GSDBS:
         return result
 
     def schemaQuery(self, dtablename):
-        statement = "{ __type(name: \"" + "gun" + "\") {name fields { name type { name kind } } } }"
+        statement = "{ __type(name: \"" + dtablename + "\") {name fields { name type { name kind } } } }"
         try:
             result = self.executeStatement(statement)
         except:
@@ -351,9 +351,9 @@ class GSDBS:
             return None
         return result
 
-    def asyncDropDTable(self, dtablename):
+    async def asyncDropDTable(self, dtablename):
         statement = f"""mutation {{\n\tdropDTable(dtablename: {dtablename})\n}}"""
-        result = self.AsyncExecuteStatement(statement)
+        result = await self.asyncExecuteStatement(statement)
         return result
 
     def dropDTable(self, dtablename):
